# Tutorial: CLI

## Prerequisites

1. [Install Ibis Birdbrain](/install.qmd)

## Overview

With Ibis Birdbrain installed, you can use the `birdbrain` command-line
interface (CLI):

```bash
$ birdbrain
```

## Next steps

[Learn how to work with Ibis Birdbrain in Python](/tutorials/python.qmd).
